ArrOgpuModule

Struct ArrOgpuModule 

pub struct ArrOgpuModule { /* private fields */ }

Implementations

Source

impl ArrOgpuModule

Source

impl ArrOgpuModule

pub fn array_from_vector( &self, vector: &[f32], shape: &[u32], ) -> Result<GpuArray, ArrOgpuErr>

Source

impl ArrOgpuModule

pub fn create_metadata_compound( &self, pointer: [u32; 2], len: u32, dim: u32, offset: u32, shape: [u32; 8], stride: [u32; 8], o_stride: [u32; 8], ) -> MetadataCompound

Source

impl ArrOgpuModule

pub fn new<T>(&self, array: T) -> Result<GpuArray, ArrOgpuErr>
where T: FlatteTrait,

Source

impl ArrOgpuModule

pub fn array_view_from_array<'a>( &self, array: &'a GpuArray, ) -> Result<GpuArrayView<'a, GpuArray>, ArrOgpuErr>

Source

impl ArrOgpuModule

pub fn create_metadata_binding( &self, pointer: &[u32], shape: &[u32], iters: &[u32], stride: &[u32], offset: &u32, ) -> (BindGroupLayout, BindGroup)

Source

impl ArrOgpuModule

pub fn get_heap(&self) -> Vec<f32>

Source

impl ArrOgpuModule

pub fn index<'a, A>( &self, array: &'a A, index: &[i32], ) -> Result<GpuArrayView<'a, A>, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn broadcast<'a, A>( &self, array: &'a A, broadcast: &[u32], ) -> Result<GpuArrayView<'a, A>, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn slicing<'a, A>( &self, array: &'a A, slice: &[SliceRangeNegativeAble], ) -> Result<GpuArrayView<'a, A>, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn to_shape<'a, A>( &self, array: &'a A, shape: &[u32], ) -> Result<GpuArrayView<'a, A>, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn permute<'a, A>( &self, array: &'a A, permute: &[u32], ) -> Result<GpuArrayView<'a, A>, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn add<'a, A, B>( &self, array_a: &'a A, array_b: &'a B, ) -> Result<GpuArray, ArrOgpuErr>

arguments can be arrays and floats can only be the second argument

Source

impl ArrOgpuModule

pub fn div<'a, A, B>( &self, array_a: &'a A, array_b: &'a B, ) -> Result<GpuArray, ArrOgpuErr>

arguments can be arrays and floats can only be the second argument

Source

impl ArrOgpuModule

pub fn mul<'a, A, B>( &self, array_a: &'a A, array_b: &'a B, ) -> Result<GpuArray, ArrOgpuErr>

arguments can be arrays and floats can only be the second argument

Source

impl ArrOgpuModule

pub fn sub<'a, A, B>( &self, array_a: &'a A, array_b: &'a B, ) -> Result<GpuArray, ArrOgpuErr>

arguments can be arrays and floats can only be the second argument

Source

impl ArrOgpuModule

pub fn matmul<A, B>( &self, array_a: &A, array_b: &B, ) -> Result<GpuArray, ArrOgpuErr>

Source

impl ArrOgpuModule

pub fn dot_product<A, B>( &self, array_a: &A, array_b: &B, ) -> Result<GpuArray, ArrOgpuErr>

Source

impl ArrOgpuModule

pub fn sum<A>(&self, array_a: &A) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn sum_axis<A>( &self, array: &A, axis: &[u32], ) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn sum_axis_keep_dim<A>( &self, array: &A, axis: &[u32], ) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn abs<A>(&self, array: &A) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn log2<A>(&self, array: &A) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn powf<A, B>(&self, array: &A, power: &B) -> Result<GpuArray, ArrOgpuErr>

Source

impl ArrOgpuModule

pub fn powi<A, B>(&self, array: &A, power: &B) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute, B: PowTrait + PowInt,

Source

impl ArrOgpuModule

pub fn cos<A>(&self, array: &A) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn sin<A>(&self, array: &A) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn tan<A>(&self, array: &A) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn sqrt<A>(&self, array: &A) -> Result<GpuArray, ArrOgpuErr>
where A: ArrayCompute,

Source

impl ArrOgpuModule

pub fn init( arr_o_gpu_module_init: ArrOgpuModuleInit, ) -> Result<ArrOgpuModule, ArrOgpuErr>

Source

impl ArrOgpuModule